@@ -47,7 +47,9 @@ function init() {
  * Enables the plugin by adding listeners and icons as necessary
  */
 function enable() {
-  this._settings = ExtensionUtils.getSettings("org.gnome.shell.extensions.shortcuts");
+  this._settings = ExtensionUtils.getSettings(
+    "org.gnome.shell.extensions.shortcuts"
+  );
   this._settings.connect("changed::show-icon", this._toggleIcon.bind(this));
   _custom_shortcut_handler = this._settings.connect(
     "changed::use-custom-shortcuts",
@@ -312,10 +314,9 @@ function _setShortcutsFile() {
 }
 
 function _setTransparency() {
-  if (!this._settings.get_boolean("use-transparency")) {
-    //    this._settings.set_int("visibility", 100);
-    _visibility = 1;
-  } else {
+  if (this._settings.get_boolean("use-transparency")) {
     _visibility = this._settings.get_int("visibility") / 100;
+  } else {
+    _visibility = 1;
   }
 }
